"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.envList = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const fetch_1 = require("@pnpm/fetch");
const node_resolver_1 = require("@pnpm/node.resolver");
const error_1 = require("@pnpm/error");
const semver_1 = __importDefault(require("semver"));
const getNodeMirror_1 = require("./getNodeMirror");
const node_1 = require("./node");
const parseNodeEditionSpecifier_1 = require("./parseNodeEditionSpecifier");
const utils_1 = require("./utils");
async function envList(opts, params) {
    if (opts.remote) {
        const nodeVersionList = await listRemoteVersions(opts, params[0]);
        // Make the newest version located in the end of output
        return nodeVersionList.reverse().join('\n');
    }
    const { currentVersion, versions } = await listLocalVersions(opts);
    return versions
        .map(nodeVersion => `${nodeVersion === currentVersion ? '*' : ' '} ${nodeVersion}`)
        .join('\n');
}
exports.envList = envList;
async function listLocalVersions(opts) {
    const nodeBaseDir = (0, node_1.getNodeVersionsBaseDir)(opts.pnpmHomeDir);
    if (!(0, fs_1.existsSync)(nodeBaseDir)) {
        throw new error_1.PnpmError('ENV_NO_NODE_DIRECTORY', `Couldn't find Node.js directory in ${nodeBaseDir}`);
    }
    const { nodeLink } = await (0, utils_1.getNodeExecPathAndTargetDir)(opts.pnpmHomeDir);
    const nodeVersionDirs = await fs_1.promises.readdir(nodeBaseDir);
    return nodeVersionDirs.reduce(({ currentVersion, versions }, nodeVersion) => {
        const nodeVersionDir = path_1.default.join(nodeBaseDir, nodeVersion);
        const nodeExec = (0, utils_1.getNodeExecPathInNodeDir)(nodeVersionDir);
        if (nodeLink?.startsWith(nodeVersionDir)) {
            currentVersion = nodeVersion;
        }
        if (semver_1.default.valid(nodeVersion) && (0, fs_1.existsSync)(nodeExec)) {
            versions.push(nodeVersion);
        }
        return { currentVersion, versions };
    }, { currentVersion: undefined, versions: [] });
}
async function listRemoteVersions(opts, versionSpec) {
    const fetch = (0, fetch_1.createFetchFromRegistry)(opts);
    const { releaseChannel, versionSpecifier } = (0, parseNodeEditionSpecifier_1.parseNodeEditionSpecifier)(versionSpec ?? '');
    const nodeMirrorBaseUrl = (0, getNodeMirror_1.getNodeMirror)(opts.rawConfig, releaseChannel);
    const nodeVersionList = await (0, node_resolver_1.resolveNodeVersions)(fetch, versionSpecifier, nodeMirrorBaseUrl);
    return nodeVersionList;
}
//# sourceMappingURL=envList.js.map