"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.envRemove = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const error_1 = require("@pnpm/error");
const fetch_1 = require("@pnpm/fetch");
const logger_1 = require("@pnpm/logger");
const node_resolver_1 = require("@pnpm/node.resolver");
const remove_bins_1 = require("@pnpm/remove-bins");
const rimraf_1 = __importDefault(require("@zkochan/rimraf"));
const parseNodeEditionSpecifier_1 = require("./parseNodeEditionSpecifier");
const utils_1 = require("./utils");
const getNodeMirror_1 = require("./getNodeMirror");
const node_1 = require("./node");
async function envRemove(opts, params) {
    if (!opts.global) {
        throw new error_1.PnpmError('NOT_IMPLEMENTED_YET', '"pnpm env use <version>" can only be used with the "--global" option currently');
    }
    const fetch = (0, fetch_1.createFetchFromRegistry)(opts);
    const { releaseChannel, versionSpecifier } = (0, parseNodeEditionSpecifier_1.parseNodeEditionSpecifier)(params[0]);
    const nodeMirrorBaseUrl = (0, getNodeMirror_1.getNodeMirror)(opts.rawConfig, releaseChannel);
    const nodeVersion = await (0, node_resolver_1.resolveNodeVersion)(fetch, versionSpecifier, nodeMirrorBaseUrl);
    const nodeDir = (0, node_1.getNodeVersionsBaseDir)(opts.pnpmHomeDir);
    if (!nodeVersion) {
        throw new error_1.PnpmError('COULD_NOT_RESOLVE_NODEJS', `Couldn't find Node.js version matching ${params[0]}`);
    }
    const versionDir = path_1.default.resolve(nodeDir, nodeVersion);
    if (!(0, fs_1.existsSync)(versionDir)) {
        throw new error_1.PnpmError('ENV_NO_NODE_DIRECTORY', `Couldn't find Node.js directory in ${versionDir}`);
    }
    const { nodePath, nodeLink } = await (0, utils_1.getNodeExecPathAndTargetDir)(opts.pnpmHomeDir);
    if (nodeLink?.includes(versionDir)) {
        (0, logger_1.globalInfo)(`Node.js version ${nodeVersion} was detected as the default one, removing ...`);
        const npmPath = path_1.default.resolve(opts.pnpmHomeDir, 'npm');
        const npxPath = path_1.default.resolve(opts.pnpmHomeDir, 'npx');
        try {
            await Promise.all([
                (0, remove_bins_1.removeBin)(nodePath),
                (0, remove_bins_1.removeBin)(npmPath),
                (0, remove_bins_1.removeBin)(npxPath),
            ]);
        }
        catch (err) { // eslint-disable-line
            if (err.code !== 'ENOENT')
                throw err;
        }
    }
    await (0, rimraf_1.default)(versionDir);
    return `Node.js ${nodeVersion} is removed
${versionDir}`;
}
exports.envRemove = envRemove;
//# sourceMappingURL=envRemove.js.map